@@ -17,9 +17,6 @@
 from __future__ import print_function
 
 import os
-import sys
-import tempfile
-import testscenarios
 
 try:
     import cStringIO as io
@@ -96,8 +93,9 @@ class SkipFileWrites(base.BaseTestCase):
                       option_dict=self.option_dict)
         self.assertEqual(
             not os.path.exists(self.filename),
-            (self.option_value.lower() in options.TRUE_VALUES
-             or self.env_value is not None))
+            (self.option_value.lower() in options.TRUE_VALUES or
+             self.env_value is not None))
+
 
 _changelog_content = """7780758\x00Break parser\x00 (tag: refs/tags/1_foo.1)
 04316fe\x00Make python\x00 (refs/heads/review/monty_taylor/27519)
@@ -128,6 +126,7 @@ def _make_old_git_changelog_format(line):
     refname = refname.replace('tag: ', '')
     return '\x00'.join((sha, msg, refname))
 
+
 _old_git_changelog_content = '\n'.join(
     _make_old_git_changelog_format(line)
     for line in _changelog_content.split('\n'))
@@ -165,7 +164,7 @@ class GitLogsTest(base.BaseTestCase):
             self.assertIn("------", changelog_contents)
             self.assertIn("Refactor hooks file", changelog_contents)
             self.assertIn(
-                "Bug fix: create_stack() fails when waiting",
+                r"Bug fix: create\_stack() fails when waiting",
                 changelog_contents)
             self.assertNotIn("Refactor hooks file.", changelog_contents)
             self.assertNotIn("182feb3", changelog_contents)
@@ -179,7 +178,7 @@ class GitLogsTest(base.BaseTestCase):
             self.assertNotIn("ev)il", changelog_contents)
             self.assertNotIn("e(vi)l", changelog_contents)
             self.assertNotIn('Merge "', changelog_contents)
-            self.assertNotIn('1_foo.1', changelog_contents)
+            self.assertNotIn(r'1\_foo.1', changelog_contents)
 
     def test_generate_authors(self):
         author_old = u"Foo Foo <email@foo.com>"
@@ -224,17 +223,29 @@ class GitLogsTest(base.BaseTestCase):
             self.assertTrue(co_author in authors)
 
 
+class _SphinxConfig(object):
+    man_pages = ['foo']
+
+
 class BaseSphinxTest(base.BaseTestCase):
 
     def setUp(self):
         super(BaseSphinxTest, self).setUp()
 
+        # setup_command requires the Sphinx instance to have some
+        # attributes that aren't set normally with the way we use the
+        # class (because we replace the constructor). Add default
+        # values directly to the class definition.
+        import sphinx.application
+        sphinx.application.Sphinx.messagelog = []
+        sphinx.application.Sphinx.statuscode = 0
+
         self.useFixture(fixtures.MonkeyPatch(
             "sphinx.application.Sphinx.__init__", lambda *a, **kw: None))
         self.useFixture(fixtures.MonkeyPatch(
             "sphinx.application.Sphinx.build", lambda *a, **kw: None))
         self.useFixture(fixtures.MonkeyPatch(
-            "sphinx.config.Config.man_pages", ['foo']))
+            "sphinx.application.Sphinx.config", _SphinxConfig))
         self.useFixture(fixtures.MonkeyPatch(
             "sphinx.config.Config.init_values", lambda *a: None))
         self.useFixture(fixtures.MonkeyPatch(
@@ -304,9 +315,8 @@ class BuildSphinxTest(BaseSphinxTest):
         build_doc = packaging.LocalBuildDoc(self.distr)
         build_doc.finalize_options()
 
-        self.assertEqual(2, len(build_doc.builders))
+        self.assertEqual(1, len(build_doc.builders))
         self.assertIn('html', build_doc.builders)
-        self.assertIn('man', build_doc.builders)
 
         build_doc = packaging.LocalBuildDoc(self.distr)
         build_doc.builders = ''
@@ -365,113 +375,73 @@ class BuildSphinxTest(BaseSphinxTest):
         self.assertEqual(["builder1", "builder2"], build_doc.builders)
 
 
-class ParseRequirementsTestScenarios(base.BaseTestCase):
-
-    versioned_scenarios = [
-        ('non-versioned', {'versioned': False, 'expected': ['bar']}),
-        ('versioned', {'versioned': True, 'expected': ['bar>=1.2.3']})
-    ]
-
-    scenarios = [
-        ('normal', {'url': "foo\nbar", 'expected': ['foo', 'bar']}),
-        ('normal_with_comments', {
-            'url': "# this is a comment\nfoo\n# and another one\nbar",
-            'expected': ['foo', 'bar']}),
-        ('removes_index_lines', {'url': '-f foobar', 'expected': []}),
-    ]
-
-    scenarios = scenarios + testscenarios.multiply_scenarios([
-        ('ssh_egg_url', {'url': 'git+ssh://foo.com/zipball#egg=bar'}),
-        ('git_https_egg_url', {'url': 'git+https://foo.com/zipball#egg=bar'}),
-        ('http_egg_url', {'url': 'https://foo.com/zipball#egg=bar'}),
-    ], versioned_scenarios)
-
-    scenarios = scenarios + testscenarios.multiply_scenarios(
-        [
-            ('git_egg_url',
-                {'url': 'git://foo.com/zipball#egg=bar', 'name': 'bar'})
-        ], [
-            ('non-editable', {'editable': False}),
-            ('editable', {'editable': True}),
-        ],
-        versioned_scenarios)
-
-    def test_parse_requirements(self):
-        tmp_file = tempfile.NamedTemporaryFile()
-        req_string = self.url
-        if hasattr(self, 'editable') and self.editable:
-            req_string = ("-e %s" % req_string)
-        if hasattr(self, 'versioned') and self.versioned:
-            req_string = ("%s-1.2.3" % req_string)
-        with open(tmp_file.name, 'w') as fh:
-            fh.write(req_string)
-        self.assertEqual(self.expected,
-                         packaging.parse_requirements([tmp_file.name]))
-
-
-class ParseRequirementsTest(base.BaseTestCase):
+class APIAutoDocTest(base.BaseTestCase):
 
     def setUp(self):
-        super(ParseRequirementsTest, self).setUp()
-        (fd, self.tmp_file) = tempfile.mkstemp(prefix='openstack',
-                                               suffix='.setup')
+        super(APIAutoDocTest, self).setUp()
 
-    def test_parse_requirements_override_with_env(self):
-        with open(self.tmp_file, 'w') as fh:
-            fh.write("foo\nbar")
-        self.useFixture(
-            fixtures.EnvironmentVariable('PBR_REQUIREMENTS_FILES',
-                                         self.tmp_file))
-        self.assertEqual(['foo', 'bar'],
-                         packaging.parse_requirements())
+        # setup_command requires the Sphinx instance to have some
+        # attributes that aren't set normally with the way we use the
+        # class (because we replace the constructor). Add default
+        # values directly to the class definition.
+        import sphinx.application
+        sphinx.application.Sphinx.messagelog = []
+        sphinx.application.Sphinx.statuscode = 0
 
-    def test_parse_requirements_override_with_env_multiple_files(self):
-        with open(self.tmp_file, 'w') as fh:
-            fh.write("foo\nbar")
-        self.useFixture(
-            fixtures.EnvironmentVariable('PBR_REQUIREMENTS_FILES',
-                                         "no-such-file," + self.tmp_file))
-        self.assertEqual(['foo', 'bar'],
-                         packaging.parse_requirements())
+        self.useFixture(fixtures.MonkeyPatch(
+            "sphinx.application.Sphinx.__init__", lambda *a, **kw: None))
+        self.useFixture(fixtures.MonkeyPatch(
+            "sphinx.application.Sphinx.build", lambda *a, **kw: None))
+        self.useFixture(fixtures.MonkeyPatch(
+            "sphinx.application.Sphinx.config", _SphinxConfig))
+        self.useFixture(fixtures.MonkeyPatch(
+            "sphinx.config.Config.init_values", lambda *a: None))
+        self.useFixture(fixtures.MonkeyPatch(
+            "sphinx.config.Config.__init__", lambda *a: None))
+        from distutils import dist
+        self.distr = dist.Distribution()
+        self.distr.packages = ("fake_package",)
+        self.distr.command_options["build_sphinx"] = {
+            "source_dir": ["a", "."]}
+        self.sphinx_options = self.distr.command_options["build_sphinx"]
+        pkg_fixture = fixtures.PythonPackage(
+            "fake_package", [("fake_module.py", b""),
+                             ("another_fake_module_for_testing.py", b""),
+                             ("fake_private_module.py", b"")])
+        self.useFixture(pkg_fixture)
+        self.useFixture(base.DiveDir(pkg_fixture.base))
+        self.pbr_options = self.distr.command_options.setdefault('pbr', {})
+        self.pbr_options["autodoc_index_modules"] = ('setup.cfg', 'True')
 
-    def test_get_requirement_from_file_empty(self):
-        actual = packaging.get_reqs_from_files([])
-        self.assertEqual([], actual)
+    def test_default_api_build_dir(self):
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.run()
 
-    def test_parse_requirements_python_version(self):
-        with open("requirements-py%d.txt" % sys.version_info[0],
-                  "w") as fh:
-            fh.write("# this is a comment\nfoobar\n# and another one\nfoobaz")
-        self.assertEqual(['foobar', 'foobaz'],
-                         packaging.parse_requirements())
+        print('PBR OPTIONS:', self.pbr_options)
+        print('DISTR OPTIONS:', self.distr.command_options)
 
-    def test_parse_requirements_right_python_version(self):
-        with open("requirements-py1.txt", "w") as fh:
-            fh.write("thisisatrap")
-        with open("requirements-py%d.txt" % sys.version_info[0],
-                  "w") as fh:
-            fh.write("# this is a comment\nfoobar\n# and another one\nfoobaz")
-        self.assertEqual(['foobar', 'foobaz'],
-                         packaging.parse_requirements())
+        self.assertTrue(os.path.exists("api/autoindex.rst"))
+        self.assertTrue(os.path.exists("api/fake_package.fake_module.rst"))
+        self.assertTrue(
+            os.path.exists(
+                "api/fake_package.fake_private_module.rst"))
+        self.assertTrue(
+            os.path.exists(
+                "api/fake_package.another_fake_module_for_testing.rst"))
 
+    def test_different_api_build_dir(self):
+        # Options have to come out of the settings dict as a tuple
+        # showing the source and the value.
+        self.pbr_options['api_doc_dir'] = (None, 'contributor/api')
+        build_doc = packaging.LocalBuildDoc(self.distr)
+        build_doc.run()
 
-class ParseDependencyLinksTest(base.BaseTestCase):
+        print('PBR OPTIONS:', self.pbr_options)
+        print('DISTR OPTIONS:', self.distr.command_options)
 
-    def setUp(self):
-        super(ParseDependencyLinksTest, self).setUp()
-        (fd, self.tmp_file) = tempfile.mkstemp(prefix="openstack",
-                                               suffix=".setup")
-
-    def test_parse_dependency_normal(self):
-        with open(self.tmp_file, "w") as fh:
-            fh.write("http://test.com\n")
-        self.assertEqual(
-            ["http://test.com"],
-            packaging.parse_dependency_links([self.tmp_file]))
-
-    def test_parse_dependency_with_git_egg_url(self):
-        with open(self.tmp_file, "w") as fh:
-            fh.write("-e git://foo.com/zipball#egg=bar")
-        self.assertEqual(
-            ["git://foo.com/zipball#egg=bar"],
-            packaging.parse_dependency_links([self.tmp_file]))
+        self.assertTrue(os.path.exists("contributor/api/autoindex.rst"))
+        self.assertTrue(
+            os.path.exists("contributor/api/fake_package.fake_module.rst"))
+        self.assertTrue(
+            os.path.exists(
+                "contributor/api/fake_package.fake_private_module.rst"))
